@@ -1,5 +1,5 @@
 test_that("Survival Return", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   model <- SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
                       method = "ITT", options = SEQopts(km.curves = TRUE))
   expect_s4_class(model, "SEQoutput")
@@ -7,7 +7,7 @@ test_that("Survival Return", {
 })
 
 test_that("Bootstrapped Survival", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   model <- SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
                       method = "ITT", options = SEQopts(km.curves = TRUE, bootstrap = TRUE, bootstrap.nboot = 2))
   expect_s4_class(model, "SEQoutput")
@@ -15,7 +15,7 @@ test_that("Bootstrapped Survival", {
 })
 
 test_that("Bootstrapped Survival - Percentile", {
-  data <- copy(SEQdata)
+  data <- data.table::copy(SEQdata)
   model <- SEQuential(data, "ID", "time", "eligible", "tx_init", "outcome", list("N", "L", "P"), list("sex"),
                       method = "ITT", options = SEQopts(km.curves = TRUE, bootstrap = TRUE, bootstrap.nboot = 2, bootstrap.CI_method = "percentile"))
   expect_s4_class(model, "SEQoutput")
